@@ -1,4 +1,4 @@
-"""Obsidian tools config handler."""
+"""glassknife config handler."""
 
 from functools import cache
 from pathlib import Path
@@ -8,7 +8,7 @@ import yaml
 from pydantic import BaseModel
 from xdg import xdg_config_home
 
-CONFIG_FILE = xdg_config_home() / "obsidian-tools" / "config.yaml"
+CONFIG_FILE = xdg_config_home() / "glassknife" / "config.yaml"
 
 
 class Vault(BaseModel):
@@ -32,9 +32,16 @@ class Vault(BaseModel):
         return self.path / self.templates_subdir
 
 
-class Config(BaseModel):
-    """Obsidian-tools configuration class."""
+class ProcessNotes(BaseModel):
+    """Configuration for process-notes."""
 
+    actions: Dict[str, str]
+
+
+class Config(BaseModel):
+    """glassknife configuration class."""
+
+    process_notes: ProcessNotes
     vaults: Dict[str, Vault]
 
 
